[Zope-CVS] CVS: Products/CompositePage/zmi - header.pt:1.2.2.1 zmi_edit.js:1.4.2.1

Shane Hathaway shane at zope.com
Fri Feb 20 11:59:49 EST 2004


Update of /cvs-repository/Products/CompositePage/zmi
In directory cvs.zope.org:/tmp/cvs-serv23783/zmi

Modified Files:
      Tag: composite-flat-ui-branch
	header.pt zmi_edit.js 
Log Message:
Started a branch for the work on a manual page composition UI.

Replaced the concept of a transformer with a "design UI".  Also
added functionality for listing what slots a template uses.


=== Products/CompositePage/zmi/header.pt 1.2 => 1.2.2.1 ===
--- Products/CompositePage/zmi/header.pt:1.2	Thu Oct  9 17:29:16 2003
+++ Products/CompositePage/zmi/header.pt	Fri Feb 20 11:59:47 2004
@@ -1,5 +1,5 @@
 <!-- zmi/header.pt -->
-<tal:block tal:define="url options/transformer/absolute_url">
+<tal:block tal:define="url options/ui/absolute_url">
 <link rel="stylesheet" type="text/css"
   tal:attributes="href string:${root/absolute_url}/manage_page_style.css" />
 <script type="text/javascript" 


=== Products/CompositePage/zmi/zmi_edit.js 1.4 => 1.4.2.1 ===
--- Products/CompositePage/zmi/zmi_edit.js:1.4	Sat Dec 27 17:56:45 2003
+++ Products/CompositePage/zmi/zmi_edit.js	Fri Feb 20 11:59:47 2004
@@ -1,15 +1,15 @@
 
 // ZMI-specific editing scripts.  Referenced by zmi/bottom.pt.
 // The variable "transformer_url" is provided by common/header.pt.
 
 function zmi_edit(element) {
   var path = escape(element.getAttribute("source_path"));
-  document.location = transformer_url + "/showElement?path=" + path;
+  document.location = ui_url + "/showElement?path=" + path;
 }
 
 function zmi_add(target) {
   // Note that target_index is also available, but the ZMI can't
   // make use of it easily.
   var path = escape(target.getAttribute("target_path"));
-  document.location = transformer_url + "/showSlot?path=" + path;
+  document.location = ui_url + "/showSlot?path=" + path;
 }
@@ -1,15 +1,15 @@
 
 // ZMI-specific editing scripts.  Referenced by zmi/bottom.pt.
-// The variable "transformer_url" is provided by common/header.pt.
+// The variable "ui_url" is provided by common/header.pt.
 
 function zmi_edit(element) {




More information about the Zope-CVS mailing list